<a id="mypy-boto3-service-quotas"></a>

# mypy-boto3-service-quotas

[![PyPI - mypy-boto3-service-quotas](https://img.shields.io/pypi/v/mypy-boto3-service-quotas.svg?color=blue)](https://pypi.org/project/mypy-boto3-service-quotas)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-service-quotas.svg?color=blue)](https://pypi.org/project/mypy-boto3-service-quotas)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-service-quotas?color=blue)](https://pypistats.org/packages/mypy-boto3-service-quotas)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.ServiceQuotas 1.20.49](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/service-quotas.html#ServiceQuotas)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-service-quotas docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_service_quotas/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-service-quotas](#mypy-boto3-service-quotas)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `ServiceQuotas`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `ServiceQuotas` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[service-quotas]'

# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[service-quotas]'

# standalone installation
python -m pip install mypy-boto3-service-quotas
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[service-quotas]` in your environment:
  `python -m pip install 'boto3-stubs[service-quotas]'`

Both type checking and auto-complete should work for `ServiceQuotas` service.
No explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto3-stubs[service-quotas]` in your environment:
  `python -m pip install 'boto3-stubs[service-quotas]'`

Both type checking and auto-complete should work for `ServiceQuotas` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[service-quotas]` in your environment:
  `python -m pip install 'boto3-stubs[service-quotas]'`
- Run `mypy` as usual

Type checking should work for `ServiceQuotas` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto3-stubs[service-quotas]` in your environment:
  `python -m pip install 'boto3-stubs[service-quotas]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ServiceQuotas` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ServiceQuotasClient` provides annotations for
`boto3.client("service-quotas")`.

```python
from boto3.session import Session

from mypy_boto3_service_quotas import ServiceQuotasClient

client: ServiceQuotasClient = Session().client("service-quotas")

# now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_service_quotas.paginator` module contains type annotations for all
paginators.

```python
from boto3.session import Session

from mypy_boto3_service_quotas import ServiceQuotasClient
from mypy_boto3_service_quotas.paginator import (
    ListAWSDefaultServiceQuotasPaginator,
    ListRequestedServiceQuotaChangeHistoryPaginator,
    ListRequestedServiceQuotaChangeHistoryByQuotaPaginator,
    ListServiceQuotaIncreaseRequestsInTemplatePaginator,
    ListServiceQuotasPaginator,
    ListServicesPaginator,
)

client: ServiceQuotasClient = Session().client("service-quotas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_aws_default_service_quotas_paginator: ListAWSDefaultServiceQuotasPaginator = client.get_paginator("list_aws_default_service_quotas")
list_requested_service_quota_change_history_paginator: ListRequestedServiceQuotaChangeHistoryPaginator = client.get_paginator("list_requested_service_quota_change_history")
list_requested_service_quota_change_history_by_quota_paginator: ListRequestedServiceQuotaChangeHistoryByQuotaPaginator = client.get_paginator("list_requested_service_quota_change_history_by_quota")
list_service_quota_increase_requests_in_template_paginator: ListServiceQuotaIncreaseRequestsInTemplatePaginator = client.get_paginator("list_service_quota_increase_requests_in_template")
list_service_quotas_paginator: ListServiceQuotasPaginator = client.get_paginator("list_service_quotas")
list_services_paginator: ListServicesPaginator = client.get_paginator("list_services")
```

<a id="literals"></a>

### Literals

`mypy_boto3_service_quotas.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_service_quotas.literals import (
    ErrorCodeType,
    ListAWSDefaultServiceQuotasPaginatorName,
    ListRequestedServiceQuotaChangeHistoryByQuotaPaginatorName,
    ListRequestedServiceQuotaChangeHistoryPaginatorName,
    ListServiceQuotaIncreaseRequestsInTemplatePaginatorName,
    ListServiceQuotasPaginatorName,
    ListServicesPaginatorName,
    PeriodUnitType,
    RequestStatusType,
    ServiceQuotaTemplateAssociationStatusType,
    ServiceName,
    PaginatorName,
)

def check_value(value: ErrorCodeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_service_quotas.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_service_quotas.type_defs import (
    DeleteServiceQuotaIncreaseRequestFromTemplateRequestRequestTypeDef,
    ErrorReasonTypeDef,
    GetAWSDefaultServiceQuotaRequestRequestTypeDef,
    GetAWSDefaultServiceQuotaResponseTypeDef,
    GetAssociationForServiceQuotaTemplateResponseTypeDef,
    GetRequestedServiceQuotaChangeRequestRequestTypeDef,
    GetRequestedServiceQuotaChangeResponseTypeDef,
    GetServiceQuotaIncreaseRequestFromTemplateRequestRequestTypeDef,
    GetServiceQuotaIncreaseRequestFromTemplateResponseTypeDef,
    GetServiceQuotaRequestRequestTypeDef,
    GetServiceQuotaResponseTypeDef,
    ListAWSDefaultServiceQuotasRequestRequestTypeDef,
    ListAWSDefaultServiceQuotasResponseTypeDef,
    ListRequestedServiceQuotaChangeHistoryByQuotaRequestRequestTypeDef,
    ListRequestedServiceQuotaChangeHistoryByQuotaResponseTypeDef,
    ListRequestedServiceQuotaChangeHistoryRequestRequestTypeDef,
    ListRequestedServiceQuotaChangeHistoryResponseTypeDef,
    ListServiceQuotaIncreaseRequestsInTemplateRequestRequestTypeDef,
    ListServiceQuotaIncreaseRequestsInTemplateResponseTypeDef,
    ListServiceQuotasRequestRequestTypeDef,
    ListServiceQuotasResponseTypeDef,
    ListServicesRequestRequestTypeDef,
    ListServicesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    MetricInfoTypeDef,
    PaginatorConfigTypeDef,
    PutServiceQuotaIncreaseRequestIntoTemplateRequestRequestTypeDef,
    PutServiceQuotaIncreaseRequestIntoTemplateResponseTypeDef,
    QuotaPeriodTypeDef,
    RequestServiceQuotaIncreaseRequestRequestTypeDef,
    RequestServiceQuotaIncreaseResponseTypeDef,
    RequestedServiceQuotaChangeTypeDef,
    ResponseMetadataTypeDef,
    ServiceInfoTypeDef,
    ServiceQuotaIncreaseRequestInTemplateTypeDef,
    ServiceQuotaTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
)

def get_structure() -> DeleteServiceQuotaIncreaseRequestFromTemplateRequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-service-quotas` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-service-quotas docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_service_quotas/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
